@@ -84,7 +84,7 @@ def getLastRun(func:macal.FunctionDefinition, scope: macal.Scope, filename: str)
     iso_now  = scope.GetVariable("defaultIsoNow").GetValue()
     fileName = f"/tmp/last_run_{org_name}.ctl"
     if os.name == "nt":
-        fileName = f"c:/temp/last_run_{name}.ctl"
+        fileName = f"c:/temp/last_run_{org_name}.ctl"
     try:
         if os.path.exists(fileName):
             with open (fileName, "r") as tf:
@@ -106,7 +106,7 @@ def setLastRun(func:macal.FunctionDefinition, scope: macal.Scope, filename: str)
     iso_now  = scope.GetVariable("isoNow").GetValue()
     fileName = f"/tmp/last_run_{org_name}.ctl";
     if os.name == "nt":
-        fileName = f"c:/temp/last_run_{name}.ctl"
+        fileName = f"c:/temp/last_run_{org_name}.ctl"
     try:
         with open(fileName, "w") as tf:
             tf.write(iso_now)
