@@ -80,7 +80,6 @@ class Interpreter:
 
 
     def InterpretInstruction(self, instruction: ast.AST, scope):
-        #print("Interpret Instruction: ", instruction, " token: ", instruction.Token)
         if instruction.Type == types.AstTypes.Assignment:
             return self.InterpretAssign(instruction, scope)
         if instruction.Type == types.AstTypes.Block:
@@ -90,7 +89,7 @@ class Interpreter:
         if instruction.Type == types.AstTypes.Continue:
             return self.InterpretContinue(instruction, scope)
         if instruction.Type == types.AstTypes.FunctionCall:
-            return self.RunFunctionCall(instruction.Name, instruction.Args, instruction.Token, scope)
+            return self.RunFunctionCall(instruction, instruction.Args, instruction.Token, scope)
         if instruction.Type == types.AstTypes.FunctionDefinition:
             return self.InterpretFunctionDefinition(instruction, scope)
         if instruction.Type == types.AstTypes.If:
@@ -227,7 +226,7 @@ class Interpreter:
         if expr.ExprType == types.ExprTypes.Grouping:
             return self.InterpretGroupingExpression(expr, scope)
         if expr.ExprType == types.ExprTypes.FunctionCall:
-            return self.RunFunctionCall(expr.Token.Lexeme, expr.Right.Left, expr.Right.Token, scope)
+            return self.RunFunctionCallFromExpr(expr.Token.Lexeme, expr.Right.Left, expr.Right.Token, scope)
         if expr.ExprType == types.ExprTypes.FunctionArgument:
             raise exceptions.RuntimeError("Function Argument type should not end up in expression interpretation.", expr.Token.Location, self.filename)
         if expr.ExprType == types.ExprTypes.ArgumentList:
@@ -412,7 +411,7 @@ class Interpreter:
 
 
 
-    def __HandleInfiniteLoopProtectionEmbeddedFunctions(self, func: ast_function_definition.FunctionDefinition, scope: mscope.Scope) -> value_item.ValueItem:
+    def HandleInfiniteLoopProtectionEmbeddedFunctions(self, func: ast_function_definition.FunctionDefinition, scope: mscope.Scope) -> value_item.ValueItem:
         if func.Name == 'setInfiniteLoopProtectionCount':
             var = scope.GetVariable('count')
             if var.GetType() != types.VariableTypes.Int:
@@ -471,7 +470,14 @@ class Interpreter:
 
 
 
-    def RunFunctionCall(self, name: str, args: typing.List[ast_expr.Expr], tok: token.LexToken, scope: mscope.Scope) -> value_item.ValueItem:
+    def RunFunctionCallFromExpr(self, name: str, args: typing.List[ast_expr.Expr], tok: token.LexToken, scope: mscope.Scope) -> value_item.ValueItem:
+        instruction = ast_function_call.FunctionCall(token.LexToken(name, types.LexTokenTypes.Identifier, tok.Location, -1), None)
+        return self.RunFunctionCall(instruction, args, tok, scope)
+
+
+
+    def RunFunctionCall(self, instruction: ast_function_call, args: typing.List[ast_expr.Expr], tok: token.LexToken, scope: mscope.Scope) -> value_item.ValueItem:
+        name = instruction.Name
         func = scope.FindFunction(name, scope)
         if func is None:
             var = scope.FindVariable(name)
@@ -489,10 +495,12 @@ class Interpreter:
             ValidateFunctionArguments(func, fnScope, self.filename)
             self.InterpretBlock(func.Block, fnScope)
         elif func.Name == 'getInfiniteLoopProtectionCount' or func.Name == 'setInfiniteLoopProtectionCount':
-            return self.__HandleInfiniteLoopProtectionEmbeddedFunctions(func, fnScope)
+            return self.HandleInfiniteLoopProtectionEmbeddedFunctions(func, fnScope)
         else:
             fnScope.RunFunction = self.RunFunction
             self.InterpretExternalFunction(func, fnScope)
+        if returnVar.Type == types.VariableTypes.Nil and returnVar.Value.Value != types.VariableTypes.Nil:
+            raise exceptions.RuntimeError(f"ExtFunction ({name}) returned nil type without wrong value ({returnVar.Value}).", tok.Location, self.filename)
         return returnVar.Value
 
 
@@ -529,7 +537,7 @@ class Interpreter:
                     else:
                         raise exceptions.RuntimeError(f'Invalid argument type ({type(kwargs[an])}) in function ({funcName}).', None, None)
                     args.append(expr)
-        result = self.RunFunctionCall(funcName, args, 
+        result = self.RunFunctionCallFromExpr(funcName, args, 
             token.LexToken(funcName, types.LexTokenTypes.Identifier, location.nullLoc(), -1), scope)
         scope.SetReturnValue(result.Value)
         return result.Value
@@ -793,7 +801,7 @@ class Interpreter:
     def GetEmptyRecord(self, fields: typing.List[ast_select_field.SelectField]) -> value_item.ValueItem:
         return_data = value_item.ValueItem().SetFromMacal(token.LexToken.nullToken(), types.VariableTypes.Record, {})
         for fld in fields:
-            return_data.Value[fld.AsName] = value_item.ValueItem().SetFromMacal(None, types.VariableTypes.Nil, types.VariableTypes.Nil)
+            return_data.Value[fld.AsName] = value_item.ValueItem().SetFromMacal(token.LexToken.nullToken(), types.VariableTypes.Nil, types.VariableTypes.Nil)
         return return_data
 
 
@@ -807,7 +815,7 @@ class Interpreter:
                 return self.GetEmptyRecord(fields)
             return_data = value_item.ValueItem().SetFromMacal(data.Token, data.Type, [])
             for rec in data.Value:
-                r = value_item.ValueItem().SetFromMacal(rec.Token, rec.Type, {})
+                r = value_item.ValueItem().SetFromMacal(rec.Token, types.VariableTypes.Record, {})
                 for fld in fields:
                     if fld.Name in rec.Value:
                         r.Value[fld.AsName] = rec.Value[fld.Name]
@@ -816,7 +824,7 @@ class Interpreter:
                 return_data.Value.append(r)
             return return_data
         elif data.Type == types.VariableTypes.Record:
-            r = value_item.ValueItem().SetFromMacal(data.Token, data.Type, {})
+            r = value_item.ValueItem().SetFromMacal(data.Token, types.VariableTypes.Record, {})
             for fld in fields:
                 if fld.Name in data.Value:
                     r.Value[fld.AsName] = data.Value[fld.Name]
