@@ -155,7 +155,6 @@ class Parser:
             operator = self.Previous(index)
             (index, right) = self.Comparison(index, inFnDef)
             expr = ast_expr.Expr(self.Previous(index)).Binary(expr, operator, right)
-            print("Equality: ", expr)
             (index, match) = self.Match(index, types.LexTokenTypes.Operator, ['!=', '=='])
         return (index, expr)
 
@@ -271,7 +270,6 @@ class Parser:
         (index, match) = self.Match(index, types.LexTokenTypes.Identifier, 'nil')
         if match:
             expr = ast_expr.Expr(self.Previous(index)).Literal(types.VariableTypes.Nil)
-            print("expr.nil: ", expr)
             return (index, expr)
         (index, match) = self.Match(index, 
                 types.LexTokenTypes.Identifier, 
