@@ -106,7 +106,8 @@ VariableTypes = VariableType([
     'Record',
     'String',
     'Type',
-    'Variable'
+    'Variable',
+    'NewArrayIndex'
 ])
 
 
