@@ -110,7 +110,7 @@ class ValueItem:
         elif isinstance(val, ast_function_definition.FunctionDefinition):
             return val
         elif isinstance(val, ValueItem):
-            print("Debug: ValueItem.fromPython(value) value is ValueItem, this is a bug that should be fix, take notes!")
+            print("Debug: ValueItem.fromPython(value) value is ValueItem, this is a bug that should be fixed, take notes!")
             ret = val.Clone()
         else:
             raise exceptions.RuntimeError(f"setValue() for type {type(val)} Not implemented.", self.Token.Location, None)
@@ -157,7 +157,7 @@ class ValueItem:
         elif self.Type == types.VariableTypes.Record:
             self.Value = tok.Lexeme
         elif self.Type == types.VariableTypes.Nil:
-            self.Value = 'nil'
+            self.Value = types.VariableTypes.Nil
         else:
             raise exceptions.RuntimeError(f"Invalid value type ({self.Type}).", tok.Location, filename)
 
